{% extends "spirit/_base.html" %}

{% load i18n %}

{% block title %}{% trans "Resend activation email" %}{% endblock %}

{% block content %}

    <h1 class="headline">{% trans "Resend activation email" %}</h1>

    <div class="login">
        <form action="." method="post">
            {% csrf_token %}
            {% include "spirit/_form.html" %}

            <input class="button" type="submit" name="post" value="{% trans "Resend email" %}" />
        </form>
    </div>

{% endblock %}