{# todo: remove this, use message #}

{% extends "spirit/_base.html" %}

{% load i18n %}

{% block title %}{% trans 'Password change successful' %}{% endblock %}

{% block content %}

    <h1 class="headline">{% trans 'Password change successful' %}</h1>

    <p><a href="{% url "spirit:user-login" %}">{% trans 'Continue to login' %}</a></p>

{% endblock %}