// Heading styles
// using golden and fourth


h1 {
  font-size: ms(1, $ms-base, $golden);
  line-height: ms(1, $base-line-height, $golden);
}

h2 {
  font-size: ms(1, $ms-base, $fourth);
  line-height: ms(1, $base-line-height, $fourth);
}